==> xlniuxdata-vipgame-1.0.1-20150205.075815-38-sources.jar: com/xunlei/niux/data/vipgame/vo/CallRecord.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * 外呼记录实体类
 * @author lisu
 * 2012-11-20
 */
@Table(tableName = "callrecord", pkFieldName = "seqid", pkFieldAssign = false)
public class CallRecord {

	private Long seqid;
	private String uid;	
	private String account;
	private String gameId;
	private Integer callType;
	private Integer listenStatus;
	private String serverId;
	private String roleName;
	private String roleGrade;
	private String lastLoginTime;
	private String leaveGameReason;
	private String gift;
	private String question;
	private String suggest;
	private String customerServiceName;
	private String callTime;
	private String remark;
	private String inputby;
	private String inputtime;
	private String editby;
	private String edittime;
	private String afterCallLoginTime;
	private Long afterCallPayAmount;
	@Column(columnName="callTime",isWhereColumn=true,operator=Operator.GE)
	private String fromcallTime;
	@Column(columnName="callTime",isWhereColumn=true,operator=Operator.LT)
	private String tocallTime;
	private Integer rebateCount;
	private Long money;
	private Long rebateMoney;
	
	
	public Integer getRebateCount() {
		return rebateCount;
	}
	public void setRebateCount(Integer rebateCount) {
		this.rebateCount = rebateCount;
	}
	public Long getMoney() {
		return money;
	}
	public void setMoney(Long money) {
		this.money = money;
	}
	public Long getRebateMoney() {
		return rebateMoney;
	}
	public void setRebateMoney(Long rebateMoney) {
		this.rebateMoney = rebateMoney;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getCustomerServiceName() {
		return customerServiceName;
	}
	public void setCustomerServiceName(String customerServiceName) {
		this.customerServiceName = customerServiceName;
	}
	public String getInputby() {
		return inputby;
	}
	public void setInputby(String inputby) {
		this.inputby = inputby;
	}
	public String getInputtime() {
		return inputtime;
	}
	public void setInputtime(String inputtime) {
		this.inputtime = inputtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public String getCallTime() {
		return callTime;
	}
	public void setCallTime(String callTime) {
		this.callTime = callTime;
	}
	public String getAccount() {
		return account;
	}
	public void setAccount(String account) {
		this.account = account;
	}
	public Integer getCallType() {
		return callType;
	}
	public void setCallType(Integer callType) {
		this.callType = callType;
	}
	public Integer getListenStatus() {
		return listenStatus;
	}
	public void setListenStatus(Integer listenStatus) {
		this.listenStatus = listenStatus;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getRoleName() {
		return roleName;
	}
	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}
	public String getRoleGrade() {
		return roleGrade;
	}
	public void setRoleGrade(String roleGrade) {
		this.roleGrade = roleGrade;
	}
	public String getLastLoginTime() {
		return lastLoginTime;
	}
	public void setLastLoginTime(String lastLoginTime) {
		this.lastLoginTime = lastLoginTime;
	}
	public String getLeaveGameReason() {
		return leaveGameReason;
	}
	public void setLeaveGameReason(String leaveGameReason) {
		this.leaveGameReason = leaveGameReason;
	}
	public String getGift() {
		return gift;
	}
	public void setGift(String gift) {
		this.gift = gift;
	}
	public String getQuestion() {
		return question;
	}
	public void setQuestion(String question) {
		this.question = question;
	}
	public String getAfterCallLoginTime() {
		return afterCallLoginTime;
	}
	public void setAfterCallLoginTime(String afterCallLoginTime) {
		this.afterCallLoginTime = afterCallLoginTime;
	}
	public Long getAfterCallPayAmount() {
		return afterCallPayAmount;
	}
	public void setAfterCallPayAmount(Long afterCallPayAmount) {
		this.afterCallPayAmount = afterCallPayAmount;
	}
	public String getFromcallTime() {
		return fromcallTime;
	}
	public void setFromcallTime(String fromcallTime) {
		this.fromcallTime = fromcallTime;
	}
	public String getTocallTime() {
		return tocallTime;
	}
	public void setTocallTime(String tocallTime) {
		this.tocallTime = tocallTime;
	}
	public String getSuggest() {
		return suggest;
	}
	public void setSuggest(String suggest) {
		this.suggest = suggest;
	}
	
	
	
}

==> xlniuxdata-vipgame-1.0.6-20150327.020757-12-sources.jar: com/xunlei/niux/data/vipgame/vo/CallRecord.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * 外呼记录实体类
 * @author lisu
 * 2012-11-20
 */
@Table(tableName = "callrecord", pkFieldName = "seqid", pkFieldAssign = false)
public class CallRecord {

	private Long seqid;
	private String uid;	
	private String account;
	private String gameId;
	private Integer callType;
	private Integer listenStatus;
	private String serverId;
	private String roleName;
	private String roleGrade;
	private String lastLoginTime;
	private String leaveGameReason;
	private String gift;
	private String question;
	private String suggest;
	private String customerServiceName;
	private String callTime;
	private String remark;
	private String inputby;
	private String inputtime;
	private String editby;
	private String edittime;
	@Column(columnName="callTime",isWhereColumn=true,operator=Operator.GE)
	private String fromcallTime;
	@Column(columnName="callTime",isWhereColumn=true,operator=Operator.LT)
	private String tocallTime;
	private Integer rebateCount;
	private Long money;
	private Long rebateMoney;
	private String picUrl;
	private String phone;
	
	
	public String getPhone() {
		return phone;
	}
	public void setPhone(String phone) {
		this.phone = phone;
	}
	public String getPicUrl() {
		return picUrl;
	}
	public void setPicUrl(String picUrl) {
		this.picUrl = picUrl;
	}
	public Integer getRebateCount() {
		return rebateCount;
	}
	public void setRebateCount(Integer rebateCount) {
		this.rebateCount = rebateCount;
	}
	public Long getMoney() {
		return money;
	}
	public void setMoney(Long money) {
		this.money = money;
	}
	public Long getRebateMoney() {
		return rebateMoney;
	}
	public void setRebateMoney(Long rebateMoney) {
		this.rebateMoney = rebateMoney;
	}
	public Long getSeqid() {
		return seqid;
	}
	public void setSeqid(Long seqid) {
		this.seqid = seqid;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getCustomerServiceName() {
		return customerServiceName;
	}
	public void setCustomerServiceName(String customerServiceName) {
		this.customerServiceName = customerServiceName;
	}
	public String getInputby() {
		return inputby;
	}
	public void setInputby(String inputby) {
		this.inputby = inputby;
	}
	public String getInputtime() {
		return inputtime;
	}
	public void setInputtime(String inputtime) {
		this.inputtime = inputtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public String getCallTime() {
		return callTime;
	}
	public void setCallTime(String callTime) {
		this.callTime = callTime;
	}
	public String getAccount() {
		return account;
	}
	public void setAccount(String account) {
		this.account = account;
	}
	public Integer getCallType() {
		return callType;
	}
	public void setCallType(Integer callType) {
		this.callType = callType;
	}
	public Integer getListenStatus() {
		return listenStatus;
	}
	public void setListenStatus(Integer listenStatus) {
		this.listenStatus = listenStatus;
	}
	public String getServerId() {
		return serverId;
	}
	public void setServerId(String serverId) {
		this.serverId = serverId;
	}
	public String getRoleName() {
		return roleName;
	}
	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}
	public String getRoleGrade() {
		return roleGrade;
	}
	public void setRoleGrade(String roleGrade) {
		this.roleGrade = roleGrade;
	}
	public String getLastLoginTime() {
		return lastLoginTime;
	}
	public void setLastLoginTime(String lastLoginTime) {
		this.lastLoginTime = lastLoginTime;
	}
	public String getLeaveGameReason() {
		return leaveGameReason;
	}
	public void setLeaveGameReason(String leaveGameReason) {
		this.leaveGameReason = leaveGameReason;
	}
	public String getGift() {
		return gift;
	}
	public void setGift(String gift) {
		this.gift = gift;
	}
	public String getQuestion() {
		return question;
	}
	public void setQuestion(String question) {
		this.question = question;
	}
	public String getFromcallTime() {
		return fromcallTime;
	}
	public void setFromcallTime(String fromcallTime) {
		this.fromcallTime = fromcallTime;
	}
	public String getTocallTime() {
		return tocallTime;
	}
	public void setTocallTime(String tocallTime) {
		this.tocallTime = tocallTime;
	}
	public String getSuggest() {
		return suggest;
	}
	public void setSuggest(String suggest) {
		this.suggest = suggest;
	}
	
	
	
}
